summaryrefslogtreecommitdiff
path: root/guix.scm
diff options
context:
space:
mode:
authorMasaya Tojo <masaya@tojo.tokyo>2020-07-15 06:10:14 +0900
committerMasaya Tojo <masaya@tojo.tokyo>2020-07-15 06:10:14 +0900
commitd7285203cb04d4e6625bcbf7222f012ba4f7cdb6 (patch)
treecae7076eee7129adbfd3dd0f3ab766c9e9675179 /guix.scm
parent1321b087545c721766690086e08be4c88e95102b (diff)
Rename proejct from qkbox to toot.
Diffstat (limited to 'guix.scm')
-rw-r--r--guix.scm24
1 files changed, 12 insertions, 12 deletions
diff --git a/guix.scm b/guix.scm
index 8cd9764..d398350 100644
--- a/guix.scm
+++ b/guix.scm
@@ -1,20 +1,20 @@
-;;; Qkbox --- TojoQK's toybox
+;;; Toot --- Mastodon Client
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Qkbox.
;;;
;;; Qkbox is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Qkbox is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Qkbox. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Toot. If not, see <http://www.gnu.org/licenses/>.
(use-modules (guix packages)
((guix licenses) #:prefix license:)
@@ -28,11 +28,11 @@
(gnu packages texinfo)
(gnu packages mastodon))
-(define guile-qkbox
+(define guile-toot
(package
- (name "guile-qkbox")
+ (name "guile-toot")
(version "0.1.0")
- (source (string-append (getcwd) "/qkbox-" version ".tar.gz"))
+ (source (string-append (getcwd) "/toot-" version ".tar.gz"))
(build-system gnu-build-system)
(native-inputs
`(("autoconf" ,autoconf)
@@ -43,9 +43,9 @@
`(("guile" ,guile-3.0)
("gulie-json" ,guile-json-4)
("guile-picture-language" ,guile-picture-language)))
- (synopsis "TojoQK's toybox")
- (description "Qkbox is TojoQK's toybox.")
- (home-page "https://gitlab.com/tojoqk/qkbox")
+ (synopsis "Mastodon Client")
+ (description "Toot is Mastodon Client.")
+ (home-page "https://gitlab.com/tojoqk/toot")
(license license:gpl3+)))
-guile-qkbox
+guile-toot
@@ -1,20 +1,20 @@
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
-;;; This file is part of Qkbox.
+;;; This file is part of Toot.
;;;
@@ -1,20 +1,20 @@
;;;
-;;; Qkbox is free software; you can redistribute it and/or modify it
+;;; Toot is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,20 +1,20 @@
;;; (at your option) any later version.
;;;
-;;; Qkbox is distributed in the hope that it will be useful, but
+;;; Toot is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU